﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Ink;
using System.Windows.Media.Imaging;
using System.IO;

namespace SLInkPresenter
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
            SetPresenterClip();
        }
        Stroke myStroke;

        private void iPresenter_MouseLeftButtonDown(object sender, MouseEventArgs e)
        {
            //让鼠标捕获数据
            iPresenter.CaptureMouse();
            //收集笔触数据点保存值StylusPointCollection集合中
            StylusPointCollection stylusPointCollection = new StylusPointCollection();
            stylusPointCollection.Add(e.StylusDevice.GetStylusPoints(iPresenter));
            //将数据点的结合保存为一个笔画
            myStroke = new Stroke(stylusPointCollection);
            //设置笔画的绘画效果，如颜色，大小等。
            myStroke.DrawingAttributes.Color = Colors.Gray;
            myStroke.DrawingAttributes.Width = 1;
            myStroke.DrawingAttributes.Height = 1;
            iPresenter.Strokes.Add(myStroke);
        }

        private void iPresenter_MouseMove(object sender, MouseEventArgs e)
        {
            //在鼠标移动的过程中将数据点加入到笔画中去。
            if (myStroke != null)
                myStroke.StylusPoints.Add(e.StylusDevice.GetStylusPoints(iPresenter));
        }

        private void iPresenter_LostMouseCapture(object sender, MouseEventArgs e)
        {
            //将笔画清空
            myStroke = null;
            iPresenter.ReleaseMouseCapture();//释放鼠标坐标
        }

        /// <summary>
        /// 设置绘画区域为InkPresenter的大小
        /// </summary>
        private void SetPresenterClip()
        {
            RectangleGeometry MyRectangleGeometry = new RectangleGeometry();
            MyRectangleGeometry.Rect = new Rect(0, 0, iPresenter.ActualWidth, iPresenter.ActualHeight);
            //设置获取绘画内容的有效区域
            iPresenter.Clip = MyRectangleGeometry;
        }

        private void button1_Click(object sender, RoutedEventArgs e)
        {
            //保存InkPresenter涂鸦板内绘画的图
            WriteableBitmap _bitmap = new WriteableBitmap(iPresenter, null);
            SaveFileDialog sfd = new SaveFileDialog();
            sfd.Filter = "PNG Files (*.png)|*.png|All Files (*.*)|*.*";
            sfd.DefaultExt = ".png";
            sfd.FilterIndex = 1;
            sfd.DefaultFileName = "DefaultImg";

            #region 具体处理，本处可以不看
            if ((bool)sfd.ShowDialog())
            {
                using (Stream fs = sfd.OpenFile())
                {
                    int width = _bitmap.PixelWidth;
                    int height = _bitmap.PixelHeight;

                    EditableImage ei = new EditableImage(width, height);

                    for (int i = 0; i < height; i++)
                    {
                        for (int j = 0; j < width; j++)
                        {
                            int pixel = _bitmap.Pixels[(i * width) + j];
                            ei.SetPixel(j, i,
                                        (byte)((pixel >> 16) & 0xFF),
                                        (byte)((pixel >> 8) & 0xFF),
                                        (byte)(pixel & 0xFF),
                                        (byte)((pixel >> 24) & 0xFF)
                            );
                        }
                    }
                    //获取流
                    Stream png = ei.GetStream();
                    int len = (int)png.Length;
                    byte[] bytes = new byte[len];
                    png.Read(bytes, 0, len);
                    fs.Write(bytes, 0, len);
                    MessageBox.Show("图片保存成功！");
                }
            }
            #endregion

        }

        private void button2_Click(object sender, RoutedEventArgs e)
        {
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = "PNG Files (*.png)|*.png|All Files (*.*)|*.*";
            ofd.FilterIndex = 1;
            ofd.InitialDirectory = "D:\\fir";
            if (ofd.ShowDialog() == true)
            {
                Stream stream = ofd.File.OpenRead();
                BitmapImage bi = new BitmapImage();
                bi.SetSource(stream);
                showIP.Source = bi;
                stream.Close();
            }
        }
    }
}
